@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION = '2.32';
+$Map::Tube::VERSION = '2.33';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube - Core library as Role (Moo) to process map data.
 
 =head1 VERSION
 
-Version 2.32
+Version 2.33
 
 =cut
 
@@ -110,10 +110,8 @@ sub get_shortest_route {
 Expects 'from' and 'to' station name and returns ref to a list of objects of type
 L<Map::Tube::Route>. On error it returns an object of type L<Map::Tube::Exception>.
 
-=head3 NOTE
-
-Be carefull when using against a large map.  You may encountered warning as
-'deep-recursion'. It throws the following error when run against London map.
+Be carefull when using against a large map. You may encountered warning as 'deep-recursion'.
+It throws the following error when run against London map.
 
 Deep recursion on subroutine "Map::Tube::_get_all_routes"
 
